# Summary

# Getting started

- [Intro](./getting-started/intro.md)
- [Start a new project](./getting-started/start_a_new_project.md)
- [Connect to an Ethereum node](./getting-started/connect_to_an_ethereum_node.md)

# Reference guide

- [Providers](./providers/providers.md)
  - [Http](./providers/http.md)
  - [WebSocket](./providers/ws.md)
  - [IPC](./providers/ipc.md)
  - [Mock](./providers/mock.md)
  - [Quorum](./providers/quorum.md)
  - [Retry](./providers/retry.md)
  - [RW](./providers/rw.md)
  - [Custom](./providers/custom.md)
  - [Advanced Usage](./providers/advanced_usage.md)
- [Middleware](./middleware/middleware.md)
  - [Builder](./middleware/builder.md)
  - [Create custom middleware](./middleware/custom.md)
  - [Gas escalator](./middleware/gas-escalator.md)
  - [Gas oracle](./middleware/gas-oracle.md)
  - [Nonce manager](./middleware/nonce-manager.md)
  - [Policy](./middleware/policy.md)
  - [Signer](./middleware/signer.md)
  - [Time lag]()
  - [Transformer]()
- [Contracts](./contracts/contracts.md)
  - [Abigen](./contracts/abigen.md)
  - [Compile](./contracts/compile.md)
  - [Creating Instances](./contracts/creating-instances.md)
  - [Deploy Anvil](./contracts/deploy-anvil.md)
  - [Deploy from ABI and bytecode](./contracts/deploy-from-abi-and-bytecode.md)
  - [Deploy Moonbeam](./contracts/doploy-moonbeam.md)
  - [Events](./contracts/events.md)
  - [Events with meta](./contracts/events-with-meta.md)
  - [Methods](contracts/methods.md)
- [Events]()
  - [Logs and filtering]()
  - [Solidity topics]()
- [Subscriptions]()
  - [Watch blocks]()
  - [Subscribe events by type]()
  - [Subscribe logs]()
- [Queries]()
  - [Blocks]()
  - [Contracts]()
  - [Events]()
  - [Paginated logs]()
  - [UniswapV2 pair]()
  - [Transactions]()
- [Transactions]()
  - [Call override]()
  - [Create raw transaction]()
  - [Create typed transaction]()
  - [Decode input]()
  - [EIP-1559]()
  - [ENS]()
  - [Estimate gas]()
  - [Get gas price]()
  - [Get gas price USD]()
  - [Remove liquidity]()
  - [Set gas for a transaction]()
  - [Send raw transaction]()
  - [Send typed transaction]()
  - [Trace]()
  - [Transaction receipt]()
  - [Transaction status]()
  - [Transfer ETH]()
- [Wallets]()
  - [Address book]()
  - [Mnemonic]()
  - [Ledger]()
  - [Local]()
  - [Permit hash]()
  - [Sign message]()
  - [Trezor]()
  - [Yubi]()
- [Big numbers](./big-numbers/intro.md)
  - [Comparison and equivalence](./big-numbers/comparison-and-equivalence.md)
  - [Conversion](./big-numbers/conversion.md)
  - [Creating Instances](./big-numbers/creating_instances.md)
  - [Math operations](./big-numbers/math-operations.md)
  - [Utilities](./big-numbers/utilities.md)
- [Anvil]()
  - [Boot anvil]()
  - [Deploy contracts]()
  - [Fork]()
  - [Testing]()
